Crate memberlist_quic

Crate memberlist_quic 

memberlist’s Transport layer based on QUIC.

Modules

futures
Abstractions for asynchronous programming.
hostaddr

hostaddr

resolver
AddressResolver trait for async.
stream_layer
Abstract the StremLayer for QuicTransport.
teststest
Exports unit tests.
unimplemented
An unimplemented transport for testing purposes only.

Structs

CIDRsPolicy
Classless Inter-Domain Routing (CIDR) policy.
Label
General approach is to prefix all packets and streams with the same structure:
Node
Node is consist of id and address, which can be used as a identifier in a distributed system.
NodeId
A unique string identifying a server for all time. The maximum length of an id is 512 bytes.
NodeIdRef
A unique string identifying a server for all time. The maximum length of an id is 512 bytes.
Packet
The packet receives from the unreliable connection.
PacketProducer
A producer for packets.
PacketSubscriber
A subscriber for packets.
QuicTransport
A Transport implementation based on QUIC
QuicTransportOptions
Used to configure a net transport.
RecvError
An error returned from Receiver::recv().
SendError
An error returned from Sender::send().
StreamProducer
A producer for promised streams.
StreamSubscriber
A subscriber for promised streams.

Enums

LabelError
Label error.
ParseNodeIdError
Errors that can occur when transforming an NodeId.
QuicTransportError
Errors that can occur when using QuicTransport.
TryRecvError
An error returned from Receiver::try_recv().
TrySendError
An error returned from Sender::try_send().

Traits

Address
Address abstraction for distributed systems
AddressResolver
Used to resolve a [SocketAddr] from a node address in async style.
CheapClone
Things that are fast to clone in the context of an application.
Connection
The connection
Id
Id abstraction for distributed systems
ProtoReader
The reader used in the memberlist proto
Transport
Transport is used to abstract over communicating with other peers. The packet interface is assumed to be best-effort and the stream interface is assumed to be reliable.
TransportError
An error for the transport layer.

Functions

packet_stream
Returns producer and subscriber for packet.
promised_stream
Returns producer and subscriber for promised stream.

Type Aliases

Domain
Domain type alias
DomainBuffer
Domain type alias
HostAddr
Host address type alias
HostAddrBuffer
Host address type alias
SmolQuicTransportsmol
QuicTransport based on smol.
TokioQuicTransporttokio
QuicTransport based on tokio.